from pycaw.pycaw import AudioUtilities, IAudioEndpointVolume
from ctypes import cast, POINTER
from comtypes import CLSCTX_ALL
import numpy as np


class Volume:
    def __init__(self):
        self._devices = AudioUtilities.GetSpeakers()
        self._interface = self._devices.Activate(
            IAudioEndpointVolume._iid_, CLSCTX_ALL, None
        )
        self._volume = cast(self._interface, POINTER(IAudioEndpointVolume))

    def get_volume(self):
        """Returns the volume of the device's speakers"""
        vol = self._volume.GetMasterVolumeLevel()
        return vol

    def set_volume(self, VolumeLevel):
        """Sets volume of the device's speakers to the user specified value"""
        self._volume.SetMasterVolumeLevel(VolumeLevel, None)

    def rangify(self, x, from_tuple: tuple, to_tuple: tuple):
        _vol = np.interp(x, from_tuple, to_tuple)
        return _vol



from setuptools import find_packages, setup

if __name__ == "__main__":
    setup(
    name = "pyspeaker",
    author = "Akshat Sabharwal",
    version = "7.0",
    package=['app'],
    author_email = "akshatsabharwal35@gmail.com",
    description = """A module for controlling the Speakers of the device
    \bMethods\b

    get_volume: Returns the current volume of the device's speakers
    set_volume: Sets the volume of the device's speakers to the given volume level.
    rangify: Interpolates or maps the given volume range of the speakers to the user-specified range.""",
    install_requires = [
        'pycaw',
        'ctypes-callable',
        'comtypes',
        'numpy'
    ]
    )
